==> spip_4.0.4.orig.tar.xz: plugins-dist/mots/lang/mots_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=km
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => 'ក្រុម​សំខាន់ ៖</b> មានអនុសាសខ្លាំងក្លា អោយជ្រើសយក មួយពាក្យគន្លឹះ ក្នុងក្រុមនេះ។', # MODIF

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'ពួកអ្នកអភិបាលសៃថ៍',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'អ្នកតែងនិពន្ធ',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'ពួក​ទស្សនាករ សៃថ៍សាធារណៈ ពេល​ពួក​គេ ​ដាក់មួយសារ ​លើមួយ​វេទិកា។',

	// I
	'icone_creation_groupe_mots' => 'បង្កើត មួយក្រុមពាក្យថ្មី',
	'icone_creation_mots_cles' => 'បង្កើត មួយពាក្យគន្លឹះថ្មី',
	'icone_modif_groupe_mots' => 'កែប្រែ ក្រុមពាក្យ នេះ',
	'icone_modifier_mot' => 'កែប្រែ ពាក្យគន្លឹះនេះ',
	'icone_mots_cles' => 'ពាក្យ​គន្លឹះ',
	'icone_supprimer_groupe_mots' => 'លប់​ក្រុម​នេះ',
	'icone_voir_tous_mots_cles' => 'បង្ហាញ គ្រប់ពាក្យគន្លឹះ',
	'info_articles_lies_mot' => 'អត្ថបទ​ដែល​ទាក់ទង​ទៅ​នឹង​ពាក្យ​គន្លឹះ​នេះ',
	'info_changer_nom_groupe' => 'ផ្លាស់​ប្ដូរ​ឈ្មោះ​ក្រុម​នេះ ៖',
	'info_creation_mots_cles' => 'បង្កើត និងកំណត់ទំរង់ រាល់ពាក្យគន្លឹះ នៃសៃថ៍ នៅទីនេះ',
	'info_dans_groupe' => 'ក្នុង​ក្រុម ៖',
	'info_delet_mots_cles' => 'អ្នក​បាន​ស្នើ​លប់​ពាក្យ​គន្លឹះ <b>@titre_mot@</b> (@type_mot@) ។ ពាក្យ​គន្លឹះ​នេះ​ត្រូវ​បាន​ភ្ជាប់​ទំនាក់ទំនង​ទៅ​នឹង <b>@texte_lie@</b> អ្នក​ត្រូវ​បញ្ជាក់​អំពី​សេចក្ដីសម្រេច  នេះ ៖', # MODIF
	'info_groupe_important' => 'ក្រុម​សំខាន់',
	'info_modifier_mot' => 'កែប្រែ ពាក្យគន្លឹះ៖',
	'info_mots_cles' => 'ពាក្យ​គន្លឹះ',
	'info_mots_cles_association' => 'ពាក្យ​គន្លឹះ​នៅ​ក្នុង​ក្រុម​នេះ​អាច​ទាក់ទិន​ទៅ​នឹងៈ',
	'info_oui_suppression_mot_cle' => 'ខ្ញុំ ចងើលុបចេញរហូត ពាក្យគន្លឹះនេះ។',
	'info_question_mots_cles' => 'អ្នក ចង់ប្រើប្រាស់ ពាក្យគន្លឹះនានា លើសៃថ៍ របស់អ្នក?',
	'info_qui_attribue_mot_cle' => 'ពាក្យ​គន្លឹះ​នៅ​ក្នុង​ក្រុម​នេះ​អាច​ត្រូវ​បាន​ផ្ទេរ​ដោយៈ',
	'info_retirer_mot' => 'ដកចេញ ពាក្យនេះ',
	'info_retirer_mots' => 'ដកចេញ គ្រប់ពាក្យ​',
	'info_rubriques_liees_mot' => 'ផ្នែក​ទាក់ទិន​ទៅ​នឹង​ពាក្យ​គន្លឹះ​នេះ',
	'info_selection_un_seul_mot_cle' => 'អ្នក​អាច​ជ្រើសយក ម្តង ត្រឹម<b>មួយពាក្យគន្លឹះ</b> ក្នុង​ក្រុម​នេះ​។', # MODIF
	'info_supprimer_mot' => 'លុបចេញ ពាក្យនេះ',
	'info_titre_mot_cle' => 'ឈ្មោះ ឬ ចំណងជើង នៃពាក្យគន្លឹះនេះ',
	'info_un_mot' => 'ពាក្យ​គន្លឹះ​មួយ​ម្ដងៗ',
	'item_ajout_mots_cles' => 'អនុញ្ញាត ​បន្ថែម​ពាក្យ​គ​ន្លឺះ ​ទៅ​វេទិកា',
	'item_non_ajout_mots_cles' => 'មិន​អនុញ្ញាត​ចំពោះ​ការ​បន្ថែម​ពាក្យ​គន្លឹះ​ដល់​វេទិកា',
	'item_non_utiliser_config_groupe_mots_cles' => 'មិន​ប្រើប្រាស់​ទម្រង់​ខ្ពស់ៗ​នៃ​ក្រុម​ពាក្យ​គន្លឹះ',
	'item_non_utiliser_mots_cles' => 'មិន​ប្រើប្រាស់​ពាក្យ​គន្លឹះ',
	'item_utiliser_config_groupe_mots_cles' => 'ប្រើប្រាស់​ទម្រង់​ខ្ពស់​នៃ​ក្រុម​ពាក្យ​គន្លឹះ',
	'item_utiliser_mots_cles' => 'ប្រើប្រាស់​ពាក្យ​គន្លឹះ',

	// L
	'logo_mot_cle' => 'ឡូ​ហ្គោ​របស់​ពាក្យ​គន្លឹះ',

	// T
	'texte_config_groupe_mots_cles' => 'តើ​លោក​អ្នក​ត្រូវការ​បើកមុខ​ងារ​ទម្រង់​ខ្ពស់​នៃ​ក្រុម​ពាក្យ​គន្លឹះ​ដែរ​ឬទេ ដោយ​កំណត់​ជាក់លាក់ ឧទាហរណ៍ ពាក្យ​ជាក់លាក់​មួយ​ក្នុង​ក្រុម​អាច​ត្រូវ​បាន​ជ្រើ​រើស ដែល​ក្រុម​នោះ​មាន​សារៈសំខាន់​.......?', # MODIF
	'texte_mots_cles' => 'ពាក្យ​គន្លឹះ​អនុញ្ញាត​លោក​អ្នក​ឱ្យ​បង្កើត​ទំនាក់ទំនង​ក្នុង​តំបន់​រវាង​អត្ថបទ​ដែល​មិន​ទាក់ទិន​នឹង​ទីតាំង​ជើ​ឿ​ស​រើស​របស់​ពួក​គេ​។ តាម​របៀប​នេះ លោក​អ្នក​អាច​ពង្រឹង​ចរណ៍​នៃ​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក ឬ​អាច​ប្រើ​លក្ខណៈ​ទាំងនេះ ដើម្បី​កែសម្រួល​អត្ថបទ នៅ​ក្នុង​ទម្រង់​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក​។.',
	'texte_mots_cles_dans_forum' => 'តើ​លោក​អ្នកមាន​បំណង​អនុញ្ញាត​ចំពោះ​ការ​ប្រើប្រាស់​ពាក្យ​គន្លឹះ ដែល​អ្នក​ទស្សនា​អាច​ជ្រើសរើស​បាន​ដែរ​ឬទេ នៅ​ក្នុង​វេទិកា​វ៉ិ​ប​សាយ​សាធារណៈ​? (​ប្រ​យ័​ត្នៈ ដើម្បី​ប្រើប្រាស់​ជម្រើស​នេះ​ឱ្យ​បាន​ត្រឹមត្រូវ គឺ​មាន​លក្ខណៈ​ស្មុគស្មាញ​បន្ដិច​។​)',
	'texte_nouveau_mot' => 'ពាក្យ​គន្លឹះ​ថ្មី',
	'titre_config_groupe_mots_cles' => 'ទម្រង់​របស់​ក្រុម​ពាក្យ​គន្លឹះ',
	'titre_gauche_mots_edit' => 'ពាក្យ លេខ៖',
	'titre_mots_cles_dans_forum' => 'ពាក្យគន្លឹះ ក្នុងទីប្រជុំមតិ នៃសៃថ៍សាធារណះ',
	'titre_mots_tous' => 'ពាក្យ​គន្លឹះ',
	'titre_nouveau_groupe' => 'ក្រុម​ថ្មី',
	'titre_page_mots_tous' => 'ពាក្យ​គន្លឹះ'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=km
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => 'ក្រុម​សំខាន់ ៖</b> មានអនុសាសខ្លាំងក្លា អោយជ្រើសយក មួយពាក្យគន្លឹះ ក្នុងក្រុមនេះ។', # MODIF

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'ពួកអ្នកអភិបាលសៃថ៍',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'អ្នកតែងនិពន្ធ',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'ពួក​ទស្សនាករ សៃថ៍សាធារណៈ ពេល​ពួក​គេ ​ដាក់មួយសារ ​លើមួយ​វេទិកា។',

	// I
	'icone_creation_groupe_mots' => 'បង្កើត មួយក្រុមពាក្យថ្មី',
	'icone_creation_mots_cles' => 'បង្កើត មួយពាក្យគន្លឹះថ្មី',
	'icone_modif_groupe_mots' => 'កែប្រែ ក្រុមពាក្យ នេះ',
	'icone_modifier_mot' => 'កែប្រែ ពាក្យគន្លឹះនេះ',
	'icone_mots_cles' => 'ពាក្យ​គន្លឹះ',
	'icone_supprimer_groupe_mots' => 'លប់​ក្រុម​នេះ',
	'icone_voir_tous_mots_cles' => 'បង្ហាញ គ្រប់ពាក្យគន្លឹះ',
	'info_articles_lies_mot' => 'អត្ថបទ​ដែល​ទាក់ទង​ទៅ​នឹង​ពាក្យ​គន្លឹះ​នេះ',
	'info_changer_nom_groupe' => 'ផ្លាស់​ប្ដូរ​ឈ្មោះ​ក្រុម​នេះ ៖',
	'info_creation_mots_cles' => 'បង្កើត និងកំណត់ទំរង់ រាល់ពាក្យគន្លឹះ នៃសៃថ៍ នៅទីនេះ',
	'info_dans_groupe' => 'ក្នុង​ក្រុម ៖',
	'info_delet_mots_cles' => 'អ្នក​បាន​ស្នើ​លប់​ពាក្យ​គន្លឹះ <b>@titre_mot@</b> (@type_mot@) ។ ពាក្យ​គន្លឹះ​នេះ​ត្រូវ​បាន​ភ្ជាប់​ទំនាក់ទំនង​ទៅ​នឹង <b>@texte_lie@</b> អ្នក​ត្រូវ​បញ្ជាក់​អំពី​សេចក្ដីសម្រេច  នេះ ៖', # MODIF
	'info_groupe_important' => 'ក្រុម​សំខាន់',
	'info_modifier_mot' => 'កែប្រែ ពាក្យគន្លឹះ៖',
	'info_mots_cles' => 'ពាក្យ​គន្លឹះ',
	'info_mots_cles_association' => 'ពាក្យ​គន្លឹះ​នៅ​ក្នុង​ក្រុម​នេះ​អាច​ទាក់ទិន​ទៅ​នឹងៈ',
	'info_oui_suppression_mot_cle' => 'ខ្ញុំ ចងើលុបចេញរហូត ពាក្យគន្លឹះនេះ។',
	'info_question_mots_cles' => 'អ្នក ចង់ប្រើប្រាស់ ពាក្យគន្លឹះនានា លើសៃថ៍ របស់អ្នក?',
	'info_qui_attribue_mot_cle' => 'ពាក្យ​គន្លឹះ​នៅ​ក្នុង​ក្រុម​នេះ​អាច​ត្រូវ​បាន​ផ្ទេរ​ដោយៈ',
	'info_retirer_mot' => 'ដកចេញ ពាក្យនេះ',
	'info_retirer_mots' => 'ដកចេញ គ្រប់ពាក្យ​',
	'info_rubriques_liees_mot' => 'ផ្នែក​ទាក់ទិន​ទៅ​នឹង​ពាក្យ​គន្លឹះ​នេះ',
	'info_selection_un_seul_mot_cle' => 'អ្នក​អាច​ជ្រើសយក ម្តង ត្រឹម<b>មួយពាក្យគន្លឹះ</b> ក្នុង​ក្រុម​នេះ​។', # MODIF
	'info_supprimer_mot' => 'លុបចេញ ពាក្យនេះ',
	'info_titre_mot_cle' => 'ឈ្មោះ ឬ ចំណងជើង នៃពាក្យគន្លឹះនេះ',
	'info_un_mot' => 'ពាក្យ​គន្លឹះ​មួយ​ម្ដងៗ',
	'item_ajout_mots_cles' => 'អនុញ្ញាត ​បន្ថែម​ពាក្យ​គ​ន្លឺះ ​ទៅ​វេទិកា',
	'item_non_ajout_mots_cles' => 'មិន​អនុញ្ញាត​ចំពោះ​ការ​បន្ថែម​ពាក្យ​គន្លឹះ​ដល់​វេទិកា',
	'item_non_utiliser_config_groupe_mots_cles' => 'មិន​ប្រើប្រាស់​ទម្រង់​ខ្ពស់ៗ​នៃ​ក្រុម​ពាក្យ​គន្លឹះ',
	'item_non_utiliser_mots_cles' => 'មិន​ប្រើប្រាស់​ពាក្យ​គន្លឹះ',
	'item_utiliser_config_groupe_mots_cles' => 'ប្រើប្រាស់​ទម្រង់​ខ្ពស់​នៃ​ក្រុម​ពាក្យ​គន្លឹះ',
	'item_utiliser_mots_cles' => 'ប្រើប្រាស់​ពាក្យ​គន្លឹះ',

	// L
	'logo_mot_cle' => 'ឡូ​ហ្គោ​របស់​ពាក្យ​គន្លឹះ',

	// T
	'texte_config_groupe_mots_cles' => 'តើ​លោក​អ្នក​ត្រូវការ​បើកមុខ​ងារ​ទម្រង់​ខ្ពស់​នៃ​ក្រុម​ពាក្យ​គន្លឹះ​ដែរ​ឬទេ ដោយ​កំណត់​ជាក់លាក់ ឧទាហរណ៍ ពាក្យ​ជាក់លាក់​មួយ​ក្នុង​ក្រុម​អាច​ត្រូវ​បាន​ជ្រើ​រើស ដែល​ក្រុម​នោះ​មាន​សារៈសំខាន់​.......?', # MODIF
	'texte_mots_cles' => 'ពាក្យ​គន្លឹះ​អនុញ្ញាត​លោក​អ្នក​ឱ្យ​បង្កើត​ទំនាក់ទំនង​ក្នុង​តំបន់​រវាង​អត្ថបទ​ដែល​មិន​ទាក់ទិន​នឹង​ទីតាំង​ជើ​ឿ​ស​រើស​របស់​ពួក​គេ​។ តាម​របៀប​នេះ លោក​អ្នក​អាច​ពង្រឹង​ចរណ៍​នៃ​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក ឬ​អាច​ប្រើ​លក្ខណៈ​ទាំងនេះ ដើម្បី​កែសម្រួល​អត្ថបទ នៅ​ក្នុង​ទម្រង់​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក​។.',
	'texte_mots_cles_dans_forum' => 'តើ​លោក​អ្នកមាន​បំណង​អនុញ្ញាត​ចំពោះ​ការ​ប្រើប្រាស់​ពាក្យ​គន្លឹះ ដែល​អ្នក​ទស្សនា​អាច​ជ្រើសរើស​បាន​ដែរ​ឬទេ នៅ​ក្នុង​វេទិកា​វ៉ិ​ប​សាយ​សាធារណៈ​? (​ប្រ​យ័​ត្នៈ ដើម្បី​ប្រើប្រាស់​ជម្រើស​នេះ​ឱ្យ​បាន​ត្រឹមត្រូវ គឺ​មាន​លក្ខណៈ​ស្មុគស្មាញ​បន្ដិច​។​)',
	'texte_nouveau_mot' => 'ពាក្យ​គន្លឹះ​ថ្មី',
	'titre_config_groupe_mots_cles' => 'ទម្រង់​របស់​ក្រុម​ពាក្យ​គន្លឹះ',
	'titre_gauche_mots_edit' => 'ពាក្យ លេខ៖',
	'titre_mots_cles_dans_forum' => 'ពាក្យគន្លឹះ ក្នុងទីប្រជុំមតិ នៃសៃថ៍សាធារណះ',
	'titre_mots_tous' => 'ពាក្យ​គន្លឹះ',
	'titre_nouveau_groupe' => 'ក្រុម​ថ្មី',
	'titre_page_mots_tous' => 'ពាក្យ​គន្លឹះ',
];
